
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.19.5',
    'branch_nick': 'patch-0-1_19_5_preparation',
    'revision_id': '9e14d56c9d958e5348b19ddc7e5fa45d4a778807',
    'revno': 7951
}
